@@ -1,17 +1,18 @@
 package App::ListPrereqs;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.05'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 our %SPEC;
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(list_prereqs);
 
-our $VERSION = '0.04'; # VERSION
-
 $SPEC{list_prereqs} = {
     v => 1.1,
     summary => 'List prerequisites of a Perl module',
@@ -155,7 +156,7 @@ sub list_prereqs {
 }
 
 1;
-#ABSTRACT: List prerequisites of a Perl module
+# ABSTRACT: List prerequisites of a Perl module
 
 __END__
 
@@ -169,7 +170,7 @@ App::ListPrereqs - List prerequisites of a Perl module
 
 =head1 VERSION
 
-This document describes version 0.04 of App::ListPrereqs (from Perl distribution App-ListPrereqs), released on 2014-09-04.
+This document describes version 0.05 of App::ListPrereqs (from Perl distribution App-ListPrereqs), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -184,10 +185,12 @@ Currently uses MetaCPAN API and by default caches API results for 24 hours.
 
 =head2 list_prereqs(%args) -> [status, msg, result, meta]
 
-List prerequisites of a Perl module.
+{en_US List prerequisites of a Perl module}.
 
+{en_US 
 Currently skips prerequisites which are modules already in core (for installed
 perl version).
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -195,20 +198,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<module>* => I<array>
 
-Perl module(s) to check.
+{en_US Perl module(s) to check}.
 
 =item * B<raw> => I<bool> (default: 0)
 
-Return raw result.
+{en_US Return raw result}.
 
 =item * B<recursive> => I<bool> (default: 0)
 
-Whether to check recursively.
+{en_US Whether to check recursively}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -218,7 +219,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 SEE ALSO
 
@@ -246,7 +247,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
